@@ -49,13 +49,29 @@ class Element(etree._Element):
             lat = float(self.element.attrib['lat'])
             lon = float(self.element.attrib['lon'])
             return Coord(lat, lon)
+
+        # elements obtained with 'out center;' in overpass
+        if self.element.tag == "way" or self.element.tag == "relation":
+            for tag in self.element:
+                if tag.tag != "center":
+                    continue
+                lat = float(tag.attrib['lat'])
+                lon = float(tag.attrib['lon'])
+                return Coord(lat, lon)
+
         return self.data.get_coords_of_complex_object(self.element)
 
     def get_bbox(self, verbose=False):
         return self.data.get_bbox_of_object(self.element, verbose)
 
+    def get_type(self):
+        return self.element.tag
+
+    def get_id(self):
+        return self.element.attrib['id']
+
     def get_link(self):
-        return ("https://www.openstreetmap.org/" + self.element.tag + "/" + self.element.attrib['id'])
+        return ("https://www.openstreetmap.org/" + self.get_type() + "/" + self.get_id())
 
 class Data(object):
     def __init__(self, filename_with_osm_data):
